categorical_sample_size: Estimate the sample size for a variable in function of its...

View source: R/utils.R

categorical_sample_sizeR Documentation

Estimate the sample size for a variable in function of its categories.

Description

Estimate the sample size for a variable in function of its categories.

Usage

categorical_sample_size(categories, increment = 10)

Arguments

categories

A vector containing the number of categories of each variable.

increment

A number as a constant to which the sample size is incremented as a product.

Value

The sample size for a categorical variable based on a ordered permutation heuristic approximation of its categories.


msu documentation built on Oct. 7, 2026, 1:07 a.m.