joint_shannon_entropy: Estimation of the Joint Shannon entropy for two categorical...

View source: R/shannon_entropy.R

joint_shannon_entropyR Documentation

Estimation of the Joint Shannon entropy for two categorical variables.

Description

The joint Shannon entropy provides an estimation of the measure of uncertainty between two random variables (see https://en.wikipedia.org/wiki/Joint_entropy).

Usage

joint_shannon_entropy(x, y)

joint_H(x, y)

Arguments

x

A factor as the represented categorical variable.

y

A factor as the represented categorical variable.

Value

Joint Shannon entropy estimation for variables x and y.

See Also

shannon_entropy for the entropy for a single variable and multivar_joint_shannon_entropy for the entropy associated with more than two random variables.

Examples

joint_shannon_entropy(factor(c(0,0,1,1)), factor(c(0,1,0,1)))
joint_shannon_entropy(factor(c('a','b','c')), factor(c('c','b','a')))
## Not run: 
joint_shannon_entropy(1)
joint_shannon_entropy(c('a','b'), c('d','e'))

## End(Not run)

msu documentation built on Oct. 7, 2026, 1:07 a.m.