multivar_joint_shannon_entropy: Estimation of joint Shannon entropy for a set of categorical...

View source: R/shannon_entropy.R

multivar_joint_shannon_entropyR Documentation

Estimation of joint Shannon entropy for a set of categorical variables.

Description

The multivariate joint Shannon entropy provides an estimation of the measure of the uncertainty associated with a set of variables (see https://en.wikipedia.org/wiki/Joint_entropy).

Usage

multivar_joint_shannon_entropy(table_variables, table_class)

multivar_joint_H(table_variables, table_class)

Arguments

table_variables

A list of factors as categorical variables.

table_class

A factor representing the class of the case.

Value

Joint Shannon entropy estimation for the variable set {table_variables, table_class}.

See Also

shannon_entropy for the entropy for a single variable and joint_shannon_entropy for the entropy associated with two random variables.

Examples

multivar_joint_shannon_entropy(list(factor(c(0,1)), factor(c(1,0))),
    factor(c(1,1)))

msu documentation built on Oct. 7, 2026, 1:07 a.m.