| categorical_sample_size | R Documentation |
Estimate the sample size for a variable in function of its categories.
categorical_sample_size(categories, increment = 10)
categories |
A vector containing the number of categories of each variable. |
increment |
A number as a constant to which the sample size is incremented as a product. |
The sample size for a categorical variable based on a ordered permutation heuristic approximation of its categories.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.