View source: R/shannon_entropy.R
| multivar_joint_shannon_entropy | R Documentation |
The multivariate joint Shannon entropy provides an estimation of the measure of the uncertainty associated with a set of variables (see https://en.wikipedia.org/wiki/Joint_entropy).
multivar_joint_shannon_entropy(table_variables, table_class)
multivar_joint_H(table_variables, table_class)
table_variables |
A list of factors as categorical variables. |
table_class |
A factor representing the class of the case. |
Joint Shannon entropy estimation for the variable set
{table_variables, table_class}.
shannon_entropy for the entropy for a
single variable and
joint_shannon_entropy for the entropy
associated with two random variables.
multivar_joint_shannon_entropy(list(factor(c(0,1)), factor(c(1,0))),
factor(c(1,1)))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.